#delimit ;
set more 1;
version 5.0;
log using clcinc1a,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINC1A.DO              V : 01              *;
*    Date    : NOV 29,1995/ June 1998 E.Skoufias            *;
*    Infile  : FILE25V1 /file25v0                           *;
*    Outfile : AGINC1                                       *;
*                                                           *;
*    OBJECTIVE: Calculate Agricultural Income for crops     *;
*                                                           *;
*************************************************************;

******************* PART I: AGRICULTURE INCOME **************************;
* Agricultural Income is calculated as sum of Agricultural revenue
  and Consumption from agricultural production
;
use d:\bulgarib\ihs97\dta97\cleanihs\file25v0;
sort hhnum;
merge hhnum using strata;
tab _merge;
keep if _merge==3;
drop _merge;

tab crop;
** There are few crops coded as 50 - All crops - Recoded as Other
;
replace crop=40 if crop==50;
sum;
tab crop if kg_har==.;

** There are approximately 100 crops for which we do not have values
   for land cultivated or anything else.  What to do with them?
   I am afraid that the only reasonable thing to do is to eliminated
   them and assume that they are zero production and consumption
;
drop if kg_har==.;

*** Step 0: Take care of zero values for current prices prices;

** Note that we have current prices on 288 observations and unit price on 300
observations, for those who reported selling their harvest. So to get the
total revenue we are going to use the current crop prices.
For those cases where the prices are not reported we are going to use
median prices by commodity and area
;

gen flagp1=0;
replace flagp1=1 if curr_pr==0 & kg_sold>0 & kg_sold~=.;
replace flagp1=2 if curr_pr==. & kg_sold>0 & kg_sold~=.;
replace flagp1=3 if (curr_pr==0 | curr_pr==.) & kg_sold==0;
tab flagp1;

** Price should not be equal to zero if the qty sold is greater than zero,
so we will consider those prices to be missing;
replace curr_pr=. if flagp1==1 | flagp1==2;

**STEP 2: Calculate the mean and STD of price and qty. by crops;
egen mamt=mean(kg_harv), by(crop);
egen samt=sd(kg_harv), by(crop);
egen namt=count(kg_harv), by(crop);
egen mprice=mean(curr_pr), by(crop);
egen sprice=sd(curr_pr), by(crop);
egen nprice=count(curr_pr), by(crop);

save agstep01,replace;
sort crop;
qui by crop: gen a=_n ;
keep if a==1;

format mamt samt %7.2f;
format mpri spri %5.2f;
format namt npri %5.0f;
list crop mamt samt namt mpri spri npri, noobs nodisplay;
clear;
use agstep01;

**STEP 3: Check for outliers-both qty and price by distr and locality;

** For prices;
gen flag1=1 if curr_pr>mprice+sprice*2 & curr_pr~=.;
gen flag2=1 if curr_pr>mprice*5 & curr_pr~=.;

tab flag1 flag2;
tab crop flag1;
tab crop flag2;

replace curr_pr=. if flag1==1 | flag2==1;

egen medianp =median(curr_pr), by(crop loc_typ);
egen nmedianp=median(curr_pr), by(crop);
lab var medianp "median crop price";

** Notice that some price are not available: We will supply them
;
replace nmedianp=15 if crop==3   ;
replace nmedianp=10 if crop==8   ;
replace nmedianp=10 if crop==9   ;
replace nmedianp=30 if crop==14  ;
replace nmedianp=60 if crop==22  ;
replace nmedianp=30 if crop==27  ;
replace nmedianp=60 if crop==29  ;
replace nmedianp=60 if crop==31  ;
;
gen price=curr_pr;
replace price=medianp if price==.;
replace price=nmedianp if price==.;


** Check for outliers for output consumed, used for seed, salaries, barter;
** This is done by careful observation, item by item;
** Note that quantities consumed should be estimated using the
   residual from harvest from sales and other allocations.
   The values that are still missing should be replaced using
   the ratio consumption to land available. But the results are
   very unrealible we better stick with median consumption.
;
gen flag3=1 if kg_harv>mamt+samt*2 & kg_harv~=.;
gen flag4=1 if kg_harv>mamt*5 & kg_harv~=.;
tab flag3 flag4;
tab crop flag3;
tab crop flag4;
tab crop if flag3==1 & flag4==1;
replace kg_harv=. if flag3==1 & flag4==1;
;
sum crop kg* price;



sum kg_harv, detail;
scalar kgh99=_result(17);
replace kg_harv=.  if kg_harv>kgh99;

sum kg_consu, detail;
scalar kgc99=_result(17);
replace kg_consu=. if kg_consu>kgc99;

sum kg_input, detail;
scalar kgi99=_result(17);
replace kg_input=. if kg_input>kgi99;

sum kg_given, detail;
scalar kgg99=_result(17);
replace kg_given=. if kg_given>kgg99;

sum kg_barte, detail;
scalar kgb99=_result(17);
replace kg_barte=. if kg_barte>kgb99;

replace kg_consu=. if kg_consu>kg_harv & kg_cons~=.;
replace kg_input=. if kg_input>kg_harv & kg_inpu~=.;
replace kg_given=. if kg_given>kg_harv & kg_give~=.;
replace kg_barte=. if kg_barte>kg_harv & kg_bart~=.;

** Step 6: Compute value of Agriculture sales -
   we use the reported amount of sales
;
replace kg_sold=50 if kg_harv~=. & kg_sold==.;

gen rev=kg_sold*price;

** Step 7: Compute value of Agriculture Home consumption
;
gen cons=(kg_harv-kg_sold-kg_input-kg_given);
replace cons=(kg_harv-kg_sold) if cons==.;
replace cons=. if cons<5;

replace kg_cons=cons if kg_cons==.;

sum crop kg* rev cons;

*** There are still few values of consumption (11) that are not
    evaluated. Straight median will be used
;
egen medcon  = median(kg_con), by (crop loc_typ);

** Replace the missing with median values;
tab crop if kg_cons==. , sum(medcon);
replace kg_consu=medcon if kg_consu==.;
sum crop kg*;

gen homecon=kg_consu*price;

sum crop kg* curr_pr medianp price rev home cons;

tab crop if kg_sold>0, sum(kg_sold);
tab crop if kg_sold>0, sum(rev);

tab crop if kg_con>0, sum(kg_consu);
tab crop if kg_con>0, sum(home)
;
keep hhnum crop rev homecon;
replace rev=rev/12;
replace home=home/12;
sort hhnum;
merge hhnum using strata;

collapse (sum) agcrop=rev agcon1=homecon, by (hhnum);

sum;
sort hhnum;
lab var agcrop  "Agriculture : Sales Crop";
lab var agcon1 "Agriculture : Consumption Crop";

lab data "Ag income from crop";
save aginc1, replace;

erase agstep01.dta;
log close;
