#delimit ;
set more 1;
version 5.0;
log using clcinc1b,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINC1B.DO              V : 01              *;
*    Date    : NOV 17,1995/ June 1998 E.Skoufias            *;
*    Infile  : FILE29V1                                     *;
*    Outfile : AGINC2                                       *;
*                                                           *;
*    OBJECTIVE: Calculate Agricultural Income from          *;
*               livestock                                   *;
*************************************************************;
clear;
***************  PART II: LIVESTOCK INCOME -FROM HERDS GROWTH ***************;

*  There are in general two approaches to calculate income from livestock:
   the first is to use the net growth in the heard and the second is to
   use the net of purchases, sales and consumption. The first method
   is too difficult to apply without detailed information of the herds,
   so we will use the second.
   This method does not take into account the change in heard population
   nor the change in assets.
;
use d:\bulgarib\ihs97\dta97\cleanihs\file29v1;
sort hhnum;
sum;
merge hhnum using strata;
tab _merge;
keep if _merge==3;
drop _merge;


** Step 1: adjust for inflation during the month and year of sale;
** In some cases we see that the price is reported but the time of selling
   is not - we only use the prices when we have the time of selling
   otherwise we use the median sale price
;

** Bring in the priceadj file;

tab rece_mth rece_yr;
ren rece_yr year;
ren rece_mth month;

*Note year in priceadj=1995,6,7 not just the last 2 digits;
replace year=1900+year;

sort year month;
merge year month using priceadj;
tab _merge;
drop if _merge==2;

gen price_s=price_rc*padj;
drop _merge month year cpi padj price_rc;

tab paid_m paid_y;
replace paid_m=1 if paid_y<96;
replace paid_yr=96 if paid_yr<96;
replace paid_yr=1900+paid_yr;
ren paid_yr year;
ren paid_mth month;
sort year month;
merge year month using priceadj;
tab _merge;
drop if _merge==2;

gen price_p=price_pd*padj;
drop _merge month year cpi padj price_pd;

** Step 2: get the mean and std dev. by animals;
tab animcod, sum(price_s);
tab animcod, sum(price_p);

/* Only one price available for chicken - too high */
replace price_p= 150 if anim==5;

egen mprice_s=mean(price_s), by(animcod);
egen sprice_s=sd(price_s),   by(animcod);
egen mprice_p=mean(price_p), by(animcod);
egen sprice_p=sd(price_p),   by(animcod);

** Step 3: check for outliers
           There are not too many prices to begin with
           we will rely on the few that are available
           and we will set a few by hand
;
gen flag1=1 if price_s> mprice_s+2*sprice_s & price_s~=.;
gen flag2=1 if price_s> 5*mprice_s & price_s~=.;
gen flag3=1 if price_p> mprice_p+2*sprice_p & price_p~=.;
gen flag4=1 if price_p> 4*mprice_p & price_p~=.;

tab flag1 flag2, miss;
tab animcod flag1 ;
tab animcod flag2 ;

tab flag3 flag4, miss;
tab animcod flag3 ;
tab animcod flag4 ;

** step 4: replace the outliers with missing;

replace price_s=. if flag1==1 & flag2==1;
replace price_p=. if flag3==1 & flag4==1;

** Calculate the Median price and replace missings;

egen medp_s = median(price_s), by(animcod loc_typ);
egen nmedp_s= median(price_s), by(animcod);
egen medp_p = median(price_p), by(animcod loc_typ);
egen nmedp_p= median(price_p), by(animcod);

tab animcod, sum(medp_s);
tab animcod, sum(medp_p);

replace price_s=medp_s  if price_s==.;
replace price_s=nmedp_s if price_s==.;
replace price_p=medp_p  if price_p==.;
replace price_p=nmedp_p if price_p==.;

sum animc price*;

*** Check for outliers in herd population-and replace them as missing;

sum n_purch n_cons n_sold;
tab animco if n_pur>0, sum(n_purc);
tab animco if n_con>0, sum(n_cons);
tab animco if n_sol>0, sum(n_sold);

sum n_purch, detail;
scalar npur99=_result(17);
replace n_purch=. if n_purch>npur99;

sum n_consu, detail;
scalar ncon99=_result(17);
replace n_consu=. if n_consu>ncon99;

sum n_sold, detail;
scalar nsold99=_result(17);
replace n_sold=. if n_sold>nsold99;

** Calculate the median values;

egen medpur=median(n_purch), by (animcod loc_typ);
egen medcons=median(n_consu), by (animcod loc_typ);
egen medsold=median(n_sold), by (animcod loc_typ);

** Replace the missing with median values;

replace n_purch=medpur  if n_purch==.;
replace n_consu=medcons if n_consu==.;
replace n_sold=medsold  if n_sold==.;


*** Step 5: get the livestock revenue by animals on a yearly basis.
    We will calculate the herd value based on net of purchases, from sales
    and consumption;

gen agliv= (n_sold + n_cons) * price_s - n_purc * price_p;
gen agcon= n_cons * price_s ;

sum n_* anim pri* ag*;
tab anim, sum(agliv);
tab anim, sum(agcon);

*** What about negative numbers ??
;
tab anim if agliv<0, sum(agliv);
tab anim if agcon<0, sum(agcon);

** Make the livestock herdval monthly;

replace agli=agli/12;
replace agco=agco/12;

keep hhnum agli agcon;
sort hhnum;
merge hhnum using strata;
tab _merge;

collapse (sum) aglivst=agli agcon2=agcon,  by (hhnum);
sum;
lab dat "Ag Income Livestock";
lab var aglivst "Agriculture : Livestock Net sales";
lab var agcon2 "Agriculture : Livestock Home Consumption";

sort hhnum;
save aginc2, replace
;
log close;
