#delimit ;
set more 1;
version 5.0;
log using clcinc1c,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINC1C.DO              V : 01              *;
*    Date    : NOV 17,1995/ June 1998 E.Skoufias            *;
*    Infile  : FILE30V0                                     *;
*    Outfile : AGINC3                                       *;
*                                                           *;
*    OBJECTIVE: Calculate Agricultural Income from          *;
*               animal products                             *;
*************************************************************;

************* PART III: AGRICULTURE REVENUE FROM ANIMAL PRODUCTS *********;
use d:\bulgarib\ihs97\dta97\cleanihs\file30v0;
sort hhnum;
merge hhnum using strata;
tab _merge;
keep if _merge==3;
drop _merge;

* Calculate the income from animal products on monthly basis
  The Income will be equal to Sales + Given + Bartered
  and the amount used for own consumption
;
tab prod if qt_pro ,sum(qt_pro);
tab prod if qt_ush ,sum(qt_ush);
tab prod if qt_sol ,sum(qt_sol);
tab prod if qt_giv ,sum(qt_giv);
tab prod if qt_bar ,sum(qt_bar);
tab prod , sum(unit);
tab prod , sum(amt);

** step 1: get the mean and std. dev.;

egen mprice=mean(unit_prc), by(prod_cde);
egen sprice=sd(unit_prc), by(prod_cde);

;
** step 2: check for outliers;
gen flag1=1 if unit_prc>4*mprice & unit_prc~=.;
gen flag2=1 if unit_prc>mprice+2*sprice * unit_prc~=.;
;

tab flag1 flag2, miss;

** step 3: replace outliers with missing values;
replace unit_prc=. if flag1==1 & flag2==1;

** step 4: calculate the median prices by product;
egen medianp =median(unit), by(prod_cde loc_typ);
egen nmedianp=median(unit), by(prod_cde);
tab prod, sum(medi);

** step 5: replace the missing with median prices;

replace unit_prc=medianp if unit==.;
replace unit_prc=nmedianp if unit==.;

*** Check for outliers in Hh use, salary and barter, by careful observation;

sum  prod qt_* unit amt;
tab prod, sum(unit);

** Set outliers to missing - I do not see too many outliers for the
   time being - live it as is ;


*** Step 6: calculate the total revenue
            It includes the quantities sold bartered and given
            away. I assume that if it is not sold for cash it is sold
            for some other remuneration ;

gen revs=0 if qt_sold==0;
replace revs=amt if amt>0 & amt~=.;
replace revs=qt_sold*unit if revs==.;

replace qt_bar=0 if qt_bar==.;
replace qt_giv=0 if qt_giv==.;

gen revb=0 if qt_bar==0;
replace revb=qt_bar*unit if revb==.;

gen revg=0 if qt_giv==0;
replace revg=qt_giv*unit if revg==.;

gen revt=revs+revb+revg;
sum rev*;

tab prod if revt>0, sum(revt);

*** Calculate the value of home consumption seperately;
gen home=qt_ushh*unit_prc;

tab prod if home>0, sum(home);

sum;
sort hhnum;
merge hhnum using strata;
tab _merge;

collapse (sum) aganimp=revt agcon3=home, by (hhnum);
sum;
sort hhnum;
lab var aganimp "Agriculture : Anim Prod Sales";
lab var agcon3 "Agriculture : Anim Prod Home Consumption";

lab data "Ag Income Animal Product";
save aginc3, replace;
;
log close;
