#delimit ;
set more 1;
version 5.0;
log using clcinc1d,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINCD.DO               V : 01              *;
*    Date    : NOV 28, 1995/ JUNE 1998 (E.SKOUFIAS)         *;
*    Infile  : FILE26V0, FILE31V0                           *;
*    Outfile : AGINC4                                       *;
*                                                           *;
*    OBJECTIVE: Calculate Agricultural costs & Incomes      *;
*                (inputs+labor+other costs)                 *;
*                                                           *;
*************************************************************;

*** Calculates the cost of Ag. inputs ***********

*   The general methodology will be to:
      a)  Limit the analysis to the Hhs that reported
          known quantities of inputs
      b)  Calculate the price of the inputs
      c)  Calculate the amount for those commodities without values
          using the median unit price
      d)  Adjust the values for inflation using the CPI - in case the
          year is not reported or the month in not reported use Jan 95
;
cap prog drop agcost;
prog define agcost;
  use d:\bulgarib\ihs97\dta97\cleanihs\file26v0,clear;
  keep if `1'kg>0 & `1'kg~=.;
  sum `1'* if `1'kg>0;
  gen `1'prix=`1'amnt/`1'kg if `1'amnt>0;
  qui sum `1'prix,det;
  local md=_result(10);
  dis `md';
  replace `1'amnt=`1'kg*`md' if `1'amnt==. | `1'amnt==0;
  sum `1'*;
  replace `1'mth=1 if `1'yr<96;
  replace `1'yr=96 if `1'yr<96;
  replace `1'yr=97 if `1'yr==.;
  replace `1'yr=96 if `1'mth>7;
  replace `1'mth=1 if `1'mth==0 | `1'mth==.;
  rename `1'mth month;
  rename `1'yr year;
  replace year=1900+year;
  sort year month;
  sum `1'* year month;

  merge year month using priceadj;
  tab _merge;
  keep if _merge==3;
  drop _merge;

  gen `1'cost=`1'amnt*padj;
  sum `1'* padj;

  collapse (sum) `1'tcost=`1'cost, by(hhnum);
  keep hhnum `1'tcost;
  save `1'temp,replace;
  sum;
end;


** Calculate the components
;
agcost f_;        /* Fertilizer */
agcost p_;        /* Pesticides */
agcost s_;        /* Seeds */

use d:\bulgarib\ihs97\dta97\cleanihs\file26v0,clear;
keep if o_amnt>0 & o_amnt~=.;
gen o_cost=o_amnt;
collapse (sum) o_tcost=o_cost, by(hhnum);
save o_temp,replace;
sum;

** Calculate the total input costs per month
;
clear;
use f_temp;

merge hhnum using p_temp;
tab _merge;
drop _merge;
sort hhnum;

merge hhnum using s_temp;
tab _merge;
drop _merge;
sort hhnum;

merge hhnum using o_temp;
tab _merge;
drop _merge;
sort hhnum;

egen aginput=rsum(f_tcost p_tcost s_tcost o_tcost);
lab var aginp "Agricultural Cost: Crop Inputs";
replace aginp = aginp/12;
sum;

keep hhnum aginp;
sort hhnum;
save agcost1, replace;
sum;

***** CALCULATE OTHER FARMING COSTS **;

clear;
use d:\bulgarib\ihs97\dta97\cleanihs\file31v0;

sum cost_pw  if  cost_pw  >0;
sum ben_cost if  ben_cost >0;
sum cost_sw  if  cost_sw  >0;
sum cost_ptr if  cost_ptr >0;
sum cost_fod if  cost_f  >0;
sum paym_lnd if  paym_lnd>0;
sum land_tax if  land_t  >0;
sum cost_srv if  cost_sr >0;
sum cost_wtr if  cost_w  >0;
sum cost_lns if  cost_lns>0;
sum cost_otr if  cost_otr>0;
sum val_subd if  val_sub >0;
sum val_srv  if  val_srv >0;
sum val_tls  if  val_tls >0;
sum val_othr if  val_oth >0;

** Calculate other income costs and revenues;
** Here there might be some problems to identify the time of reference
   sometimes it is clear, other times we have to make some assumptions
   If not clearly stated we assume that the costs are lst 12 months
;
replace cost_fod=0 if cost_fod==.;
replace land_tax=0 if land_tax==.;

gen aglabor=cost_pw + ben_cost + cost_sw/12;
gen agfeed=cost_fod/12;
gen agocost=cost_ptr/12 + paym_lnd/12 + land_tax/12 + cost_srv/12 +
            cost_wtr/12 + cost_lns/12 + cost_otr/12;

lab var aglabor "Agriculture Cost: Labor";
lab var agfeed  "Agriculture Cost: Animal Feed";
lab var agocost "Agriculture Cost: Other";

gen agoinc = val_sub/12 + val_srv/12 + val_tls/12 + val_oth/12;
lab var agoinc "Agriculture Income: Other";

keep hhnum ag*;

sum;
sort hhnum;
save agcost2, replace;

** Compile and clean up
;
use strata;
keep hhnum;
sort hhnum;
merge hhnum using agcost1;
tab _merge;
drop _merge;

sort hhnum;
merge hhnum using agcost2;
tab _merge;
drop _merge;
sum;
replace aginp=0 if aginp==.;
replace aglab=0 if aglab==.;
replace agfeed=0 if agfeed==.;
replace agocost=0 if agocost==.;
replace agoinc=0 if agoinc==.;

sort hhnum;
lab data "Ag Income Cost & Other";
save aginc4,replace;
des;
sum;
log close;

* Clean up;
erase f_temp.dta;
erase p_temp.dta;
erase s_temp.dta;
erase o_temp.dta;
erase agcost1.dta;
erase agcost2.dta;

