#delimit ;
set more 1;
version 5.0;
clear;
log using clcinc2,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINC2.DO               V : 01              *;
*    Date    : NOV 20,1995/ June 1998 E.Skoufias            *;
*    Infile  : FILE18V0                                     *;
*    Outfile : WINC1                                        *;
*                                                           *;
*    OBJECTIVE: Calculates Income from main job employment  *;
*                                                           *;                                                         *;
*************************************************************;

use d:\bulgarib\ihs97\dta97\cleanihs\file02v1;
keep hhnum idcode age_yrs gender hhm;
sort hhnum idcode;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file18v0;
tab _merge hhm, miss;

** Check number of children to verify the child allowance
;
gen a= age_y<=18;
egen chil18=sum(a), by(hhnum);
drop a;

keep if _merge==3;
drop _merge;

**  This program calculates wage income from first job;
sum;
* step 1: check for the outliers by careful observation;

gen flagh1=1 if mj_hrs>70;
replace flagh1=2 if mj_mths>4;
** to see how many outliers are there;
tab flagh1;
replace mj_hrs=40 if flagh1==1;
replace mj_mths=4 if flagh1==2;

* Create a hours worked per month variables
;
gen hours1=mj_hrs*mj_mths if mj_mths>0 & mj_mths>0;

* Flag the outliers in the income variable-by careful observation
Note: I use Carlo's definition of an outlier==value >99pctile
(I have checked this with the BIHS95);


sum mj_gros, detail;
scalar gros99=_result(17);

gen flag1=1 if (mj_gros>gros99 & mj_gros ~=. & mj_thome<gros99) |
               (mj_gros<gros99 & mj_thome>gros99 & mj_thome~=.) ;

sum mj_tax, detail;
scalar tax99=_result(17);
gen flag2=1 if mj_tax>tax99;

sum mj_deduc, detail;
scalar deduc99=_result(17);
gen flag3=1 if mj_deduc>deduc99;

sum mj_vacat, detail;
scalar vacat99=_result(17);
gen flag4=1 if mj_vacat>vacat99;

sum mj_trans, detail;
scalar trans99=_result(17);
gen flag5=1 if mj_trans>trans99;

sum mj_kind, detail;
scalar kind99=_result(17);
gen flag6=1 if mj_kind>kind99;

** step 2: replace the outliers with missing values;
sum mj*;
replace mj_gros=.   if flag1==1;
replace mj_thom=.   if flag1==1;
replace mj_tax=.    if flag2==1;
replace mj_deduc=.  if flag3==1;
replace mj_vacat=.  if flag4==1;
replace mj_trans=.  if flag5==1;
replace mj_kind=.   if flag6==1;

scalar drop gros99 tax99 deduc99 vacat99 trans99 kind99;


** step3: calculate the median values-by the type of activity, age group
          and gender.  Note that for some categiries that do not occur
          very often, it is important to calculate the means only for
          the occurring cases.  After all the missing values apply only to
          people that supposely have values;
          ;
gen catage=0;
replace catage=1 if age_y>15 & age_y<=24;
replace catage=2 if age_y>25 & age_y<=34;
replace catage=3 if age_y>35 & age_y<=54;
replace catage=4 if age_y>55 & age_y<=70;

** PROGRAM STEPS **;
cap prog drop domed ;
prog define domed ; /* To calculate medians when small group is non 0*/
  gen a=`1';
  replace a=. if `1'==0;
  egen m1 = median(a), by(`3' `4' `5');
  egen m2 = median(a);

  gen b=m1;
  replace b=m2 if b==.;
  gen m`2'=b;
  drop a b m1 m2 ;
end;

domed mj_gros  gros mj_activ catage gender;
domed mj_thome take mj_activ catage gender;

egen mratetax=median(mj_tax/mj_gros);

gen rateded=mj_ded/mj_gros;
domed rateded ded mj_activ catage gender;
replace rateded=mded if rateded==.;

domed mj_vaca vacat mj_activ catage gender;
domed mj_tran trans mj_activ catage gender;
domed mj_kind kind  mj_activ catage gender;

sum m*;

* Child allowance - it is already included in the gross pay - but
  we want to get a seperate variable.  I am not quite sure who is entitled
  to child allowance, now I assume that is families with children under 18
;
gen child1=0;
replace child1=mj_chld if mj_chld>0 & mj_chld~=.;
gen pchil18=child1/chil18;
sum pch* if mj_chl~=0;
replace mj_chl=350*chil18 if mj_chl==.;  /* Approximate value per child*/
replace child1=mj_chld if child1==0 & mj_chld>0 & mj_chld~=.;

** calculate the net income;
*  Note: basically we should get the take home pay as the main measure of
         payment, if missing we will take the the gross income minus taxes
         and deductions + child allowance
         Because we assume that take home pay includes the child allowance
         we are going to take the child allowance out to obtain net take
         home pay
;
gen wage1=mj_thome;
replace wage1=(mj_gros-mj_tax-mj_ded+mj_ch) if wage1==. | wage1==0 ;
replace wage1=mtake if wage1==.;
replace wage1=wage1 - child1 if child1*1.1<wage1;
** Estimate the other missing values
;
replace mj_gros=mgros if mj_gros==.;
replace mj_tax=mratetax * mj_gros   if mj_tax==.;
replace mj_deduc=rateded * mj_gros if mj_deduc==.;

replace mj_vacat=mvacat if mj_vacat==.;
replace mj_trans=mtran  if mj_tran==.;
replace mj_kind=mkind   if mj_kind==.;

gen winc1=wage1 + mj_vacat + mj_trans + mj_kind;

lab var hours1  "Monthly hours worked";
lab var winc1  "Wage income from main job";
lab var child1 "Child allow from main job";

sum mj_* wage winc1 chi*;

keep hhnum idcode hours winc1 mj_sect mj_empl child1;
sum;
sort hhnum idcode;
lab data "Wage income 1";
save winc1, old replace;

log close;
