#delimit ;
set more 1;
version 5.0;
log using clcinc3,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINC3.DO               V : 01              *;
*    Date    : NOV 21,1995/ June 1998 E.Skoufias            *;
*    Infile  : FILE19V0                                     *;
*    Outfile : WINC2                                        *;
*                                                           *;
*    OBJECTIVE: Calculates Income from Second job employment*;
*                                                           *;                                                         *;
*************************************************************;

clear;
use d:\bulgarib\ihs97\dta97\cleanihs\file02v1;
keep hhnum idcode age_yrs gender hhm;
sort hhnum idcode;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file19v0;
tab _merge hhm, miss;

** Check number of children to verify the child allowance
;
gen a= age_y<=18;
egen chil18=sum(a), by(hhnum);
drop a;

keep if _merge==3;
drop _merge;

**  This program calculates wage income from second job;
sum;
* step 1: check for the outliers by careful observation;

gen flagh1=1 if sj_hrs>70;
replace flagh1=2 if sj_mths>4;
** to see how many outliers are there;
tab flagh1;
replace sj_hrs=40 if flagh1==1;
replace sj_mths=4 if flagh1==2;

* Create a hours worked per month variables
;
gen hours2=sj_hrs*sj_mths if sj_mths>0 & sj_mths>0;

* Flag the outliers in the income variable-by careful observation
Note: I use Carlo's definition of an outlier==value >99pctile
(I have checked this with the BIHS95);

sum sj_gros, detail;
scalar gros99=_result(17);

gen flag1=1 if (sj_gros>gros99 & sj_gros ~=. & sj_thome<gros99) |
               (sj_gros<gros99 & sj_thome>gros99 & sj_thome~=.) ;

sum sj_tax, detail;
scalar tax99=_result(17);
gen flag2=1 if sj_tax>tax99;

sum sj_deduc, detail;
scalar deduc99=_result(17);
gen flag3=1 if sj_deduc>deduc99;

sum sj_vacat, detail;
scalar vacat99=_result(17);
gen flag4=1 if sj_vacat>vacat99;

sum sj_trans, detail;
scalar trans99=_result(17);
gen flag5=1 if sj_trans>trans99;

sum sj_recmb, detail;
scalar recmb99=_result(17);
gen flag6=1 if sj_recmb>recmb99;

** step 2: replace the outliers with missing values;
sum sj*;
replace sj_gros=.   if flag1==1;
replace sj_thom=.   if flag1==1;
replace sj_tax=.    if flag2==1;
replace sj_deduc=.  if flag3==1;
replace sj_vacat=.  if flag4==1;
replace sj_trans=.  if flag5==1;
replace sj_recmb=.   if flag6==1;

scalar drop gros99 tax99 deduc99 vacat99 trans99 recmb99;



** step3: calculate the median values-by the type of activity, age group
          and gender.  Note that for some categiries that do not occur
          very often, it is important to calculate the means only for
          the occurring cases.  After all the missing values apply only to
          people that supposely have values;
          ;
gen catage=0;
replace catage=1 if age_y>15 & age_y<=24;
replace catage=2 if age_y>25 & age_y<=34;
replace catage=3 if age_y>35 & age_y<=54;
replace catage=4 if age_y>55 & age_y<=70;

** PROGRAM STEPS **;
cap prog drop domed ;
prog define domed ; /* To calculate medians when small group is non 0*/
  gen a=`1';
  replace a=. if `1'==0;
  egen m1 = median(a), by(`3' `4' `5');
  egen m2 = median(a);

  gen b=m1;
  replace b=m2 if b==.;
  gen m`2'=b;
  drop a b m1 m2 ;
end;

domed sj_gros  gros sj_activ catage gender;
domed sj_thome take sj_activ catage gender;

egen mratetax=median(sj_tax/sj_gros);

gen rateded=sj_ded/sj_gros;
domed rateded ded sj_activ catage gender;
replace rateded=mded if rateded==.;

domed sj_vaca vacat sj_activ catage gender;
domed sj_tran trans sj_activ catage gender;
domed sj_recmb recmb  sj_activ catage gender;

sum m*;

* Child allowance - it is already included in the gross pay - but
  we want to get a seperate variable.  I am not quite sure who is entitled
  to child allowance, now I assume that is families with children under 18
;
gen child2=0;
replace child2=sj_chld if sj_chld>0 & sj_chld~=.;
gen pchil18=child2/chil18;
sum pch* if sj_chl~=0;
replace sj_chl=350*chil18 if sj_chl==.;  /* Approximate value per child*/
replace child2=sj_chld if child2==0 & sj_chld>0 & sj_chld~=.;

** calculate the net income;
*  Note: basically we should get the take home pay as the main measure of
         payment, if missing we will take the the gross income minus taxes
         and deductions + child allowance
         Because we assume that take home pay includes the child allowance
         we are going to take the child allowance out to obtain net take
         home pay
;
gen wage2=sj_thome;
replace wage2=(sj_gros-sj_tax-sj_ded+sj_ch) if wage2==.;
replace wage2=mtake if wage2==.;
replace wage2=wage2 - child2 if child2*1.1<wage2 ;

** Estimate the other missing values
;
replace sj_gros=mgros if sj_gros==.;
replace sj_tax=mratetax * sj_gros   if sj_tax==.;
replace sj_deduc=rateded * sj_gros if sj_deduc==.;

replace sj_vacat=mvacat if sj_vacat==.;
replace sj_trans=mtran  if sj_tran==.;
replace sj_recmb=mrecmb   if sj_recmb==.;

gen winc2=wage2; /* NO BENEFITS HERE MISSING WOULD MESS IT UP */

lab var hours2  "Monthly hours worked Sec Job";
lab var winc2  "Wage income from sec job";
lab var child2 "Child allow from sec job";

sum sj_* wage winc2 chi*;

keep hhnum idcode hours winc2 child2;
sum;
sort hhnum idcode;
lab data "Wage income 2";
save winc2, old replace;

log close;
