#delimit ;
set more 1;
version 5.0;
log using clcinc6,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINC6.DO               V : 01              *;
*    Date    : NOV 21,1995/ June 1998 E.Skoufias            *;
*    Infile  : File38v0,39,40,41,42,43,44v0,(44b??),45,46   *;
*    Outfile : Series of Othinc files: OTHINC1-9, OTHINC44  *;
*                                                           *;
*    OBJECTIVE: Calculates Income from social assisitance   *;
*               or Insurance/pension                        *;
*                                                           *;                                                         *;
*************************************************************;

** Little program used here and there;
cap prog drop catage;
prog define catage;
   gen catage=0;
   replace catage=1 if age_y>15 & age_y<=24;
   replace catage=2 if age_y>25 & age_y<=34;
   replace catage=3 if age_y>35 & age_y<=54;
   replace catage=4 if age_y>55 & age_y<=70;
end;

clear;
use d:\bulgarib\ihs97\dta97\cleanihs\file02v1;
keep hhnum idcode gender age_yrs hhm;
sort hhnum idcode;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file38v0;

tab _merge hhm, miss;
keep if _merge==3;
sum;

**  This step calculates income from private pension;
**step 1: check for outliers-no child allowance reported;

sum d_lastmo, detail;
scalar last99=_result(17);

gen flag1=1 if d_lastmo>last99 & d_lastmo~=.;
replace flag1=2 if d_last==.;
tab flag1;

scalar drop last99;

** step 2: replace the outliers with missing values;
replace d_lastmo=. if flag1==1;

** step 3:calculate the median values;
egen medpen=median(d_lastmo), by(age_yrs gender);

** step 4: replace the missing values with median values;
replace d_lastmo=medpen if flag1==1 | flag1==2;

rename d_lastmo privpen;
rename d_allow child3;
lab var privpen "monthly private pension";
lab var child3 "monthly child allow priv pens";

sum;
keep hhnum idcode privpen child3;
sort hhnum idcode;
save othinc1, replace;
sum privpen,det;
;
*
**  This step calculates income from state/public pension
*;
use d:\bulgarib\ihs97\dta97\cleanihs\file02v1, clear;
keep hhnum idcode gender age_y hhm;
sort hhnum idcode;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file39v0;

tab _merge hhm,miss;
keep if _merge==3;
sum;

ren ret_last pubpen;
ren ret_allo child4;
lab var child4 "monthly child allowance pub pens";
lab var pubpen "monthly public pension";

**step 1: check for outliers-no child allowance reported;
sum pubpen, detail;
scalar pubpen99=_result(17);

gen flag1=1 if pubpen>pubpen99 & pubpen~=.;
tab flag1;

scalar drop pubpen99;

** step 2: replace the outliers with missing values;
replace pubpen=. if flag1==1;
replace child4=0 if child4<10; /* No reason to receive it */

** step 3:calculate the median values;
egen medpen=median(pubpen), by(age_y gender);

** step 4: replace the missing values with median values;
replace pubpen=medpen if pubpen==.;

sum;
sort hhnum;
keep hhnum idcode pubpen child4;
sort hhnum idcode;
save othinc2, replace;
sum;

*
**  This step calculates income from survivers pension;
*;
use d:\bulgarib\ihs97\dta97\cleanihs\file02v1, clear;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file40v0;

tab _merge;
keep if _merge==3;

ren surv_lst surpen;
lab var surpen "monthly survival pension";

sum;

sum surpen, detail;

* I replace . with median;
replace surpen=23000 if (surpen==.);

sum surpen, detail;

keep hhnum idcode surpen;
sort hhnum idcode;
save othinc3, replace;

*
**  This step calculates income from disability pension;
*;
use d:\bulgarib\ihs97\dta97\cleanihs\file02v1, clear;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file41v0;

tab _merge;
keep if _merge==3;

ren dis_last dispen;
lab var dispen "monthly disability pension";

sum dispen, detail;
scalar dispen1=_result(16);
scalar dispen99=_result(17);


**step 1: check for outliers-no child allowance reported;
gen flag1=1 if ((dispen>dispen99 & disp~=.) | dispen<dispen1) ;
tab flag1;
** step 2: replace the outliers with missing values;
replace dispen=. if flag1==1;

scalar drop dispen1 dispen99;

** step 3:calculate the median values by type of job,age and gender;
egen medpen=median(dispen), by(dis_job age_yrs gender);
egen nmedpen=median(dispen), by(gender);

** step 4: replace the missing values with median values;
replace dispen=medpen if dispen==.;
replace dispen=nmedpen if dispen==.;

sum ;
keep hhnum idcode dispen;
sort hhnum idcode;
save othinc4, replace;
sum;
*
**  This step calculates income from Unemployment benefits;
*;
use d:\bulgarib\ihs97\dta97\cleanihs\file02v1, clear;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file42v0;

tab _merge;
keep if _merge==3;
drop _merge;

** Note: the unemployment benefits are given for the period of
   unemployment. If we take as a monthly value the last payment
   we might be adding the salary to the benefit and inflate the
   income of that person.
** First we are goint to limit the calculation of income to people that
   received benefits during the last 12 Months.
   Then we are goint to multiply them by the number of months they
   have received it and divide it by 12 - Monthly amount  calculated
   on a annualized basis -
;
gen flagu=1 if (un_lstm>=4 & un_lsty==96) | (un_lsty==97);
keep if flagu==1;

ren un_amnt unemben;
lab var unemben "monthly unemp. benefits";
ren un_subsi child5;
lab var child5 "monthly child subsidy";

**step 1: check for outliers-child allowance reported;

sum unemben, detail;
scalar uben99=_result(17);

sum child5, detail;
scalar child599=_result(17);

gen flag1=1 if unemben>uben99 & unemben~=.;
gen flag2=1 if child5>child599 & child~=.;
tab flag1 flag2;

** step 2: replace the outliers with missing values;
replace unemben=. if flag1==1;
replace child5=. if flag2==1;

** Step 3: Generate the medians;
egen medben=median(unemb);
egen medc5=median(child5);

** step 4: replace the missing values with median values;
replace unemben=medben if unemben==.;
replace child5=medc5 if child5==.;

tab un_lsty;
tab un_lstm;
rename un_lsty year;
rename un_lstm month;

** Include Inflation Adjustment  *
I DO NOT KNOW WHAT THIS IS ALL ABOUT
;
replace month=4 if month==0;
*replace month=7 if year==97 & month==9;
*replace month=1 if year==97 & month==12;

*To match year in preiceadj.dta;
replace year=1900+year;

sort year month;
merge year month using priceadj;
replace unemb=unemb*padj;
replace child5=child5*padj;

** Calculate the monthly variable
;
replace un_long=6 if un_long==.;
replace un_long=12 if un_long>12;

replace unemben=unem*un_long;
replace unemben=unemb/12;

sum;

keep hhnum idcode unemben child5;
sort hhnum idcode;
save othinc5, replace;
;
*
**  This step calculates income from maternal and social program benefits;
*;
use d:\bulgarib\ihs97\dta97\cleanihs\file02v1, clear;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file43v0;

tab _merge;
keep if _merge==3;

gen matben=b_amount;
lab var matben "monthly maternity benefits";

gen stipend=s_amount;
lab var stipend "monthly stipend";

gen child6=s_allow;
lab var child6 "monthly child allowance";


**** I do not do this correction;
*** we need to adjust for individuals whose benefits and stipends were
    stopped. so we will only take the number of months they got benefits
    last year and multiply by the amount received in the last month and
    then divide by 12;

tab b_stopy;
drop if b_stopy<96;

tab b_stopy  b_stopm;

*To find out how long they were receiving benefits for;
list b_starty b_startm if (b_stopy==96 & b_stopm==10);
list b_starty b_startm if (b_stopy==97 & b_stopm==2);
list b_starty b_startm if (b_stopy==97 & b_stopm==4);


gen t1=12;
*replace t1= if b_starty== & b_startm==10 & b_stopy==96 & b_stopm==10);

tab s_stopy  s_stopm;

*To find oout how long they were receiving benefits for;
list s_starty s_startm if (s_stopy==96 & s_stopm==12);
list s_starty s_startm if (s_stopy==97 & s_stopm==1);
list s_starty s_startm if (s_stopy==97 & s_stopm==7);
list s_starty s_startm if (s_stopy==97 & s_stopm==8);

gen t2=12;
*replace t2= if s_starty== & s_startm==10 & s_stopy==96 & s_stopm==10);



**step 1: check for outliers-no child allowance reported;

sum matben, detail;
scalar matben99=_result(17);
gen flag1=1 if matben>matben99;
sum stipend, detail;
scalar stip99=_result(17);
gen flag2=1 if stipend>stip99;

scalar drop matben99 stip99;

** step 2: replace the outliers with missing values;
replace matben=. if flag1==1;
replace stipend=. if flag2==1;

** step 3:calculate the median values;
catage;
egen medben=median(matben), by(catage gender);
egen medsti=median(stipend), by(catage gender);

** step 4: replace the missing values with median values;
replace matben=medben if matben==.;
replace stipend=medsti if stipend==.;

** make it on monthly basis;
replace matben=matben*t1/12;
replace stipend=stipend*t2/12;
**replace matben=2100 if hhnum==805471; /* From observation */

sum ;
keep hhnum idcode matben stipend child6;
drop if matb==. & stip==. & chil==.;
replace matb=0 if matb==.;
replace stip=0 if stip==.;
replace chi=0 if chi==.;

sort hhnum idcode;
save othinc6, replace;

sort hhnum idcode;
keep hhnum idcode matben stipend child6;
save othinc6, replace;

*
**  This step calculates income from inkind individual social benefits;
*;
use d:\bulgarib\ihs97\dta97\cleanihs\file02v1, clear;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file44v0;

tab _merge;
keep if _merge==3;

gen tranben=i_amount;
lab var tranben "monthly transp. benefits";

gen medben=m_costbe;
lab var medben "monthly medical benefits";

sum medben tranben;

tab i_stopy  i_stopm;

*To find out how long they were receiving benefits for;
list i_starty i_startm if (i_stopy==97 & i_stopm==2);

gen t1=12;
*replace t1=8 if i_starty==96 & i_startm==10 & i_stopy==97 & i_stopm==6;

**step 1: check for outliers;

sum tranben, detail;
scalar tben99=_result(17);
gen flag1=1 if tranben>tben99;
sum medben, detail;
scalar mben99=_result(17);
gen flag2=1 if medben>mben99;

scalar drop tben99 mben99;

** step 2: replace the outliers with missing values;
replace tranben=. if flag1==1;
replace medben=. if flag2==1;

** step 3:calculate the median values;
catage;
egen medtran=median(tranben), by(catage gender);
egen mben=median(medben), by(catage gender);

** step 4: replace the missing values with median values;
replace tranben=medtran if tranben==.;
replace medben=mben if medben==.;

** make it on a monthly basis;
replace tranben=tranben*t1/12;
replace medben=medben/12;

sum;
keep hhnum idcode medben tranben;
sort hhnum idcode;
sum;
save othinc7, replace;


*************************** file44b?????????????;

**  This step calculates child benefit allowance received by adults on
behalf of children (childid)
*;
use d:\bulgarib\ihs97\dta97\cleanihs\file02v1, clear;
merge hhnum idcode using
d:\bulgarib\ihs97\dta97\cleanihs\file44b;

tab _merge;
keep if _merge==3;

gen child44b=amtrecd;
lab var child44b "Child Allowanc last mo";


sum child44b amtrecd amtsuppo;


sum child44b, detail;
scalar chil99=_result(17);

replace child44b=. if child44b>chil99;

scalar drop chil99;


** step 3:calculate the median values;
catage;
egen medcb=median(child44b);

** step 4: replace the missing values with median values;
replace child44b=medcb if (child44b==.);

sum;
keep hhnum idcode child44b;
sort hhnum idcode;
sum;
save othinc44, replace;





********* HOUSEHOLD LEVEL BENEFITS ********;

*
**  This step calculates income from cash & kind HH social benefits;
*;
use d:\bulgarib\ihs97\dta97\cleanihs\file45v0, clear;
merge hhnum using strata;
tab _merge;
keep if _merge==3;
drop _merge;
keep if hlp_rec==1;
tab stop_yr;
drop if stop_yr<95;
sum;

** Make the total benefits on a monthly basis;

gen hhben=tod_val;
lab var hhben "monthly hh. social benefits";

**step 1: check for outliers-no child allowance reported;

sum hhben, detail;
scalar hhben99=_result(17);

gen flag1=1 if hhben>hhben99;

scalar drop hhben99;

** step 2: replace the outliers with missing values;
replace hhben=. if flag1==1;

** step 3:calculate the median values-by type of benefit;
egen medben=median(hhben),by(bcode);

** step 4: replace the missing values with median values;
replace hhben=medben if hhben==.;
**replace hhben=4300 if hhben==0;  /* From observation */

*** make it on a monthly basis;
replace hhben=(hhben/12);

sum hhnum bcode hhben;
tab bcode, sum(hhben);

sort hhnum;
merge hhnum using strata;
tab _merge;
collapse (sum) sb_hhold=hhben, by(hhnum);
sort hhnum;
lab var sb_hhold "Social Benefit: Household";
save othinc8, replace;
sum;

*
**  This step calculates income from other revenue;
*;
use d:\bulgarib\ihs97\dta97\cleanihs\file46v0, clear;
sort hhnum;
merge hhnum using strata;
tab _merge;
keep if _merge==3;
drop _merge;
keep if new==1;

ren tod_val othrev;
lab var othrev "other monthly revenues-asset,int etc.";

**step 1: check for outliers-no child allowance reported;

sum othrev, detail;
scalar orev99=_result(17);

gen flag1=1 if (othrev>orev99 | othrev==0);

** step 2: replace the outliers with missing values;
replace othrev=. if flag1==1;

scalar drop orev99;

** step 3:calculate the median values-by type of revenue;
egen medoth=median(othrev), by(bcode);

** step 4: replace the missing values with median values;
replace othrev=amnt_yr if othrev==.;
replace othrev=medoth if othrev==.;

** make it on a monthly basis;
replace othrev=(othrev/12);

sum bcode othrev;
tab bcode, sum(othrev);
keep if bcode<10;  /* Only income and not Expenditure */

sort hhnum;
merge hhnum using strata;
tab _merge;
collapse (sum) othrev=othrev, by(hhnum);
lab var othrev "Other revenue Income";
save othinc9, replace;
sum;
;
log close;
