#delimit ;
set more 1;
version 5.0;
log using clcinc7,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINC7.DO               V : 01              *;
*    Date    : NOV 21,1995/ June 1998 E.Skoufias            *;
*    Infile  : FILE34V1, FILE36V1                           *;
*    Outfile : OTHINC10 - OTHINC11                          *;
*                                                           *;
*    OBJECTIVE: Calculates net Income from remittances      *;
*                                                           *;
*************************************************************;


**  This step calculates income received from remittances
;
use d:\bulgarib\ihs97\dta97\cleanihs\file34v1;
merge hhnum using strata;
tab _merge;
keep if _merge==3;
drop _merge;

** step 1: check for outliers - by careful observation;
replace value=0 if q_cloth==0;
replace tot_val=0 if q_in_k==0;

sum d_cash12, detail;
scalar cash1299=_result(17);
gen flag1=1 if d_cash12>cash1299;

sum q_food, detail;
scalar food99=_result(17);
gen flag2=1 if q_food>food99;

sum value, detail;
scalar val99=_result(17);
gen flag3=1 if value>val99;

sum tot_val, detail;
scalar tval99=_result(17);
gen flag4=1 if tot_val>tval99;

tab flag1 flag2;
tab flag3 flag4;

** step 3:replace the outliers with missing values;
replace d_cash12=. if flag1==1;
replace q_food=.   if flag2==1;
replace value=.    if flag3==1;
replace tot_val=.  if flag4==1;

scalar drop cash1299 food99 val99 tval99;

** step 3: calculate the median values-by region;
egen medcash=median(d_cash12), by(region); * cash;
egen medfood=median(q_food), by(region );  * food;
egen medcloth=median(value), by(region );  * cloth;
egen medkind=median(tot_val), by(region);  * in kind;

** step 4: replace the missing with median values;

replace d_cash12=d_cash30*12 if d_cash12==.;
replace d_cash12=medcash if d_cash12==.;

replace q_food=medfood if q_food==.;

replace value=q_cloth if value==.;
replace value=medcloth if value==.;

replace tot_val=q_in if tot_val==.;
replace tot_val=medkind if tot_val==.;

*** make it on a monthly basis;

gen remitr1=d_cash12/12+q_food+(value+tot_val)/12;

lab var remitr1 "Remittance received";
sum;

sort hhnum;
merge hhnum using strata;
tab _merge;
collapse (sum) remitr=remitr1, by(hhnum);
lab var remitr "Remittance received";

sort hhnum;
save othinc10, replace;
sum;
;

**  This step calculates remittances sent from household;
;
use d:\bulgarib\ihs97\dta97\cleanihs\file36v1;
merge hhnum using strata;
tab _merge;
keep if _merge==3;
drop _merge;

** step 1: check for outliers-by careful observation;
replace value=0 if q_cloth==0;
replace tot_val=0 if q_in_k==0;

sum d_sent12, detail;
scalar sent99=_result(17);
gen flag1=1 if d_sent12>sent99;

sum q_food, detail;
scalar food99=_result(17);
gen flag2=1 if q_food>food99;

sum value, detail;
scalar val99=_result(17);
gen flag3=1 if value>val99;

sum tot_val, detail;
scalar tval99=_result(17);
gen flag4=1 if tot_val>tval99;


tab flag1 flag2;
tab flag3 flag4;

** step 3:replace the outliers with missing values;
replace d_sent12=. if flag1==1;
replace q_food=.   if flag2==1;
replace value=.    if flag3==1;
replace tot_val=.  if flag4==1;

scalar drop sent99 food99 val99 tval99;

** step 3: calculate the median values-by region;

egen medcash=median(d_sent12), by(region );
egen medfood=median(q_food), by(region );
egen medcloth=median(value), by(region );
egen medkind=median(tot_val), by(region );

** step 4: replace the missing with median values;

replace d_sent12=d_sent30*12 if d_sent12==.;
replace d_sent12=medcash if d_sent12==.;

replace q_food=medfood if q_food==.;

replace value=q_cloth if value==.;
replace value=medcloth if value==.;

replace tot_val=q_in if tot_val==.;
replace tot_val=medkind if tot_val==.;

*** make it on a monthly basis;

gen remits1=d_sent12/12+q_food+(value+tot_val)/12;

lab var remits1 "remittance sent";
sum;

sort hhnum;
merge hhnum using strata;
tab _merge;
collapse (sum) remits=remits1, by(hhnum);
lab var remits "Remittance Sent";

save othinc11, replace;
sum;
;
log close;

