#delimit ;
set more 1;
version 5.0;
log using clcinc8,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINC8.DO               V : 01              *;
*    Date    : NOV 27, 1995/ June 1998 E.Skoufias           *;
*    Infile  : FILE49V1                                     *;
*    Outfile : OTHINC12                                     *;
*                                                           *;
*    OBJECTIVE: Calculates Income from real estate          *;
*                       assets owned and  to receive        *;
*                                                           *;
*************************************************************;

use d:\bulgarib\ihs97\dta97\cleanihs\file49v1, clear;
merge hhnum using strata;
tab _merge;
keep if _merge==3;
drop _merge;

**  This step calculates income received from real estate;

* Real estate income;

** Step 1: check for outliers;
sum p_intere, detail;
scalar int99=_result(17);
gen flag1=1 if p_intere>int99 & p_inter~=.;

sum p_val_re, detail;
scalar pv99=_result(17);
gen flag2=1 if p_val_re>pv99 & p_val_re~=.;
tab flag1 flag2;

** Step 2: remove the outliers with missing;
replace p_intere=. if flag1==1;
replace p_val_re=. if flag2==1;

** Check types of properties and their value to calculate the income
   flow derived from the rental value of real estate properties.
   There are 642 cases of ownershipo reported.  320 of these they are
   rented for a fee.
   The income stream for the missing and non renting households is
   calculated using the median of the rental value of each unit
   by location.
;
tab p_typ, sum(p_nb);

gen size=p_nb if p_unit<=2;
replace size=p_nb*100 if p_unit==3;    /* Decars in Sq Meters*/

gen catunit=1 if p_unit==1;
replace catunit=2 if p_unit>1 & p_unit~=.;

tab p_typ catu, sum(size);

** Small cahnges fro very few values
;
replace size=size/10 if size>500 & p_typ==1;
replace p_per=100 if p_per==.;
replace size=2 if p_typ==4 & cat==1;
replace size=1500 if p_typ==4 & cat==2;

gen sizep=size*p_perc/100;

** Fix some unit values that might have been miscoded:
   set as number all the sizes that are less than 5 - cannot have that few
   numbers of square meters
;
replace catunit=1 if catunit==2 & size<=5;

gen asset1=p_int if p_int>0 & p_int~=.;
replace asset1=p_val_ if asset1==. & p_val_>0 & p_val_~=.;
replace asset=asset/12;
lab var asset "Rent from Real Estate";

** Calculate unit and median values;

gen unitv=asset1/sizep;
egen medass=median(unitv), by(p_typ loc_typ catuni);
egen medass2=median(unitv), by(p_typ catuni);

** Step 4: replace the missing with median values;

tab p_typ, sum(asset1);
replace asset1=medass*sizep if asset1==.;
replace asset1=medass2*sizep if asset1==.;
tab p_typ, sum(asset1);

** Final small changes
;
*replace asset=41   if p_typ==6 & asset==.;
*replace asset=1000 if p_typ==7 & asset==.;
*replace asset=1000 if p_typ==8 & asset==.;
*replace asset=2000 if asset==.;

sum;

tab p_typ,sum(asset);

sort hhnum;
merge hhnum using strata;
tab _merge;
collapse (sum) assetinc=asset1, by(hhnum);
lab var assetinc "Rents from Real Estate";

save othinc12, replace;

log close;
