#delimit ;
set more 1;
version 5.0;
log using clcinctl,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINCTL.DO              V : 01              *;
*    Date    : NOV 27, 1995/ June 1998 E.Skoufias           *;
*    Infile  : AGINC*, WINC*, OTHINC*                       *;
*    Outfile : INDINCTL, HHINCTL                            *;
*                                                           *;
*    OBJECTIVE: Sum the components of Income                *;
*               Calculate total monthly income              *;
*                                                           *;
*************************************************************;
****** First create the Household file with a few characteristics;
clear;
use strata;
sort hhnum;
keep hhnum distr loc_typ;

** REMEMBER: Files are not same dimension.
	     After each merge We need to set legimate zeros
	     to that value and some apparent zeros to missing
;
** Bring in AGRICULTURAL INCOME                            *
   in household level file aginc1 aginc2 aginc3 aginc4     *
   created using CLCINC1A.DO , B, C & D                    *
;

cap prog drop addhhf;
program define addhhf;
  while "`1'"~="" {;
     merge hhnum using `1';
     tab _merge;
     drop _merge;
     sort hhnum;
     mac shift;
   };
end;

addhhf aginc1 aginc2 aginc3 aginc4;

sum;

** Calculate total Agriculture Income & costs:
   Note that income from livestock includes home consumption
;
gen aginc= agcrop + agcon1 +
   aglivs +
   aganim +
   agcon3 +
   agoinc ;

gen aghcons= agcon1 + agcon2 + agcon3;
gen agcost = aginp  + aglab  + agfeed + agoc;
sum aginc aghcons agcost;

lab var aginc  "Agriculture: total income";
lab var aghcon "Agriculture: total home consumption";
lab var agcost "Agriculture: total costs";

lab data "Total Household income";
sort hhnum;
save hhinctl,replace;


**** CONSTRUCT AN INDIVIDUAL LEVEL INCOME FILE  *******;
*    And then add the totals the other file     *;

clear;


use d:\bulgarib\ihs97\dta97\cleanihs\file02v1;
keep hhnum idcode age_yrs gender hhm;
lab data "Individual Income file";
sort hhnum idcode;
save indinctl,replace;

cap prog drop addindf;
program define addindf;
  merge hhnum idcode using `1';
  tab _merge;
  drop if _merge==2;
  drop _merge  ;
  mac shift;
  while "`1'"~="" {;
     replace `1'=0 if `1'==. ;
     mac shift;
  };
  sort hhnum idcode;
end;

addindf winc1 hours1 winc1 child1;
addindf winc2 hours2 winc2 child2;
addindf winc3 selfinc;
addindf othinc1 privpen child3;
addindf othinc2 pubpen  child4;
addindf othinc3 surpen;
addindf othinc4 dispen;
addindf othinc5 unemb child5;
addindf othinc6 matben stip child6;
addindf othinc7 tran medben;
addindf othinc44 child44b;

keep hhnum idcode age_yrs gender hhm
     hours1 winc1 child1
     hours2 winc2 child2
     selfinc
     privpen child3
     pubpen  child4
     surpen
     dispen
     unemb child5
     matben stip child6
     tran medben child44b;

sum;
lab data "Individual Income File";
save indinctl,replace;

** Calculate summaries for each individual
   Note that we assumed that child allowance had already
   included in the take home pay, but not in the calculation of
   amounts received by the individuals in case of the social
   benefits
;
gen child = child1 + child2 + child3 + child4 + child5 + child6;

sum child child44b;

gen wage  = winc1 + winc2;

rename child child1_6;

lab var child1_6 "Child Allowance";
lab var wage  "Total Wage Income";

sort hhnum idcode;
save indinctl,old replace;

** Check a few Curiosities
;
count if wage>0 & unemben>0;
count if wage>0 & pubpen>0;
count if self>0 & unemben>0;
count if self>0 & pubpen>0;
sum;

** Create a household level file
;
collapse  (sum)
wage=wage
self=selfinc
sb_penpr=privpen
sb_penpb=pubpen
sb_surv=surpen
sb_disab=dispen
sb_unemp=unemb
sb_mater=matben
sb_stip=stip
sb_trans=tran
sb_medic=medben
sb_child=child1_6
sb_chil2=child44b, by(hhnum);

lab var wage     "Wage Income";
lab var self     "Self Employment Income";
lab var sb_penpr "Social Benefit: Pri. Pension";
lab var sb_penpb "Social Benefit: Pub Pension";
lab var sb_surv  "Social Benefit: Survival Pen";
lab var sb_disab "Social Benefit: Disability";
lab var sb_unemp "Social Benefit: Unemployemnt";
lab var sb_mater "Social Benefit: Maternal";
lab var sb_stip  "Social Benefit: Stipend";
lab var sb_trans "Social Benefit: Transport";
lab var sb_medic "Social Benefit: Medical";
lab var sb_child "Social Benefit: Child Allowance";
lab var sb_chil2 "Social Benefit: Child Allow from child44b";

sort hhnum;
save hhinc01, replace;
des;
sum;
use hhinctl;
merge hhnum using hhinc01;
tab _merge;
drop _merge;
sort hhnum;
save,replace;
erase hhinc01.dta;

** BRING IN THE REST OF THE HOUSEHOLD LEVEL FILES  **
;
addhhf othinc8 othinc9 othinc10 othinc11 othinc12;

** CALCULATE THE TOTALS  **
;
des;
sum;

** Note: Total income is equal to the sum of:
	 Net agricultural income
	 wage income and self employement income
	 social benefit income (excluding Child allowance already
	   calculated in the several income sections
	 Net Remittances (A measure of disposable income does not include
	   the amount remitted to others)
	 Other revenue
	 Rents from real estate assets
;
gen hhtminc= aginc - agcost +
     wage + self +
     sb_penpr + sb_penpb + sb_surv +
     sb_disab + sb_unemp + sb_mater + sb_stip +
     sb_trans + sb_medic + sb_hhold + sb_child+
     remitr - remits +
     othrev + assetinc ;

lab var hhtminc  "Total Hh Monthly Income";



gen hhtminc2= aginc - agcost +
     wage + self +
     sb_penpr + sb_penpb + sb_surv +
     sb_disab + sb_unemp + sb_mater + sb_stip +
     sb_trans + sb_medic + sb_hhold + sb_chil2+
     remitr - remits +
     othrev + assetinc ;

lab var hhtminc2  "Total Hh Monthly Income w/ Child44b";


** Check negetive values ;

count if hhtminc<0;
sum hhtminc if hhtminc>0,det;

sort hhnum;
save hhinctl,old replace;

log close;


